.. currentmodule:: scpper.api

API Reference
===============

The following section outlines the API of ``scpper``.

Scpper
--------

.. attributetable:: Scpper

.. autoclass:: Scpper
    :members:

Page
--------

.. attributetable:: Page

.. autoclass:: Page
    :members:

User
--------

.. attributetable:: User

.. autoclass:: User
    :members: